@@ -2,6 +2,7 @@
 import platform
 
 import requests
+from requests_toolbelt import MultipartEncoder
 
 from rapconector.document import (Document, DocumentAuthenticityResult,
                                   DocumentGroup, ExternalDocumentType)
@@ -295,14 +296,19 @@ class Client():
             identificadores no caso da inserção em lote.
         :rtype: int or list(int)
         '''
-        files = {'documentFile': document_file} if document_file else None
+        fields = {
+            'documentData': document_data,
+            'documentType': str(document_type)
+        }
+        if document_file:
+            fields['documentFile'] = document_file
+
+        encoder = MultipartEncoder(fields=fields)
+
         parsed_res = parse_or_raise(
             self.session.post(u'{}/documents'.format(self.base_url),
-                              data={
-                                  'documentData': document_data,
-                                  'documentType': document_type
-                              },
-                              files=files))
+                              data=encoder,
+                              headers={'Content-Type': encoder.content_type}))
 
         if isinstance(parsed_res, list):
             return [x['documentId'] for x in parsed_res]
