@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from requests_toolbelt import MultipartEncoder
+
 from rapconector.utils import parse_or_raise
 
 
@@ -83,18 +85,23 @@ class Document:
         :return: O identificador do documento atualizado.
         :rtype: int
         '''
-        files = {'documentFile': document_file} if document_file else None
+        fields = {
+            'documentType':
+            str(document_type) if document_type is not None else None,
+            'documentData': document_data,
+            'updateDescription': update_description
+        }
+        if document_file:
+            fields['documentFile'] = document_file
+
+        encoder = MultipartEncoder(fields=fields)
 
         return parse_or_raise(
-            self._client.session.put(u'{}/documents/{}'.format(
-                self._client.base_url, self.document_id),
-                                     data={
-                                         'documentType': document_type,
-                                         'documentData': document_data,
-                                         'updateDescription':
-                                         update_description
-                                     },
-                                     files=files))['documentId']
+            self._client.session.put(
+                u'{}/documents/{}'.format(self._client.base_url,
+                                          self.document_id),
+                data=encoder,
+                headers={'Content-Type': encoder.content_type}))['documentId']
 
     def delete(self, cascade=False):
         '''
